@@ -61,11 +61,12 @@ def start_cherrypy(config):
     from cherrypy import wsgiserver
     hostname = config['server_host']['host']
     port = int(config['server_host']['port'])
+    scheme = config['server_host']['scheme']
     app = load_app()
     server = wsgiserver.CherryPyWSGIServer((hostname, port), app)
     try:
-        logging.debug('starting cherrypy at %s:%s', hostname, port)
-        std_error_message("Starting CherryPy at %s:%s" % (hostname, port))
+        logging.debug('starting cherrypy at %s://%s:%s', scheme, hostname, port)
+        std_error_message("Starting CherryPy at %s://%s:%s" % (scheme, hostname, port))
         server.start()
     except KeyboardInterrupt:
         server.stop()
